#
# spec file for package ecwolf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ecwolf
Version:        1.4.1
Release:        3.2
Summary:        An opensource implementation of Wolfenstein3D engine
License:        GPL-2.0-only
Group:          Amusements/Games/3D/Shoot
URL:            https://maniacsvault.net/ecwolf
#Git-Clone:     https://bitbucket.org/ecwolf/ecwolf.git
Source:         https://maniacsvault.net/ecwolf/files/ecwolf/1.x/%{name}-%{version}-src.tar.xz
Patch1:         ecwolf-no-rpath.patch
Patch2:         ecwolf-fix-path.patch
Patch3:         ecwolf-fix-gcc14.patch
BuildRequires:  cmake
BuildRequires:  fluidsynth-devel
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(sdl2)
Provides:       bundled(gdtoa)
Provides:       bundled(lzma)

%description
ECWolf is a port of the Wolfenstein 3D engine based of Wolf4SDL.

%prep
%autosetup -p1 -n %{name}-%{version}-src
# remove bundled libs
rm -Rf deps/{bzip2,zlib,jpeg-6b,SDL,SDL_mixer,SDL_net,textscreen}
sed -e 's|/usr/local/share/games/wolf3d|%{_datadir}/wolf3d|g' -i docs/ecwolf.6

%build
%cmake \
    -DINTERNAL_ZLIB=OFF \
    -DINTERNAL_BZIP2=OFF \
    -DINTERNAL_JPEG=OFF \
    -DUSE_LIBTEXTSCREEN=OFF \
    -DGPL=ON
%cmake_build

%install
install -D -m 0755 build/ecwolf %{buildroot}%{_bindir}/ecwolf
install -D -m 0644 build/ecwolf.pk3 %{buildroot}%{_datadir}/ecwolf/ecwolf.pk3
install -D -m 0644 docs/ecwolf.6 %{buildroot}%{_mandir}/man6/ecwolf.6

%files
%license docs/license-gpl.txt docs/license-id.txt
%doc README.md PHILOSOPHY.md docs/changelog
%{_bindir}/ecwolf
%dir %{_datadir}/ecwolf
%{_datadir}/ecwolf/ecwolf.pk3
%{_mandir}/man6/ecwolf.6%{?ext_man}

%changelog
* Sat Nov  2 2024 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * ecwolf-fix-gcc14.patch
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Feb  6 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.4.1
  * Fixed crash when picking up Chaingun while already holding a
    Chaingun.
  * Fake Hitler actor can no longer open doors, no longer
    erroneously backs away from the player, and continues to
    "dodge" when out of sight.
  * Fixed support for gray scale PNGs.
  * Added support for 32:9 aspect ratio displays and additional
    resolutions.
* Fri Jan 20 2023 Martin Hauke <mardnh@gmx.de>
- Add patches
  * ecwolf-fix-path.patch
  * ecwolf-no-rpath.patch
- Drop patch
  * ecwolf-static-libs.patch
- Install manpage
- Update BuildRequires
- Mention bundled libs
- Update to version 1.4.0
  * LAN multiplayer for up to 11 players.
  * Actors now track their current target instead of assuming the
    one and only player.
  * Visibility for attacks is determined by geometric checks
    instead of renderer feedback.
  * The "DoomEdNum" has been deprecated and all places where they
    were used now accept actor class names directly.
  * Support for BILLBOARD flag for "3D sprites", compared to
    Wolf4SDL the angle of the actor is used allowing arbitrary
    angles.
  * Added parallax skies compatible with ROTT through sky1 in
    MAPINFO/Map definition (mostly incompatible with LZWolf's
    parallaxsky definition)
  * Added support for Wolfstone 3D and Elite Hans: Die Neue Ordnung
  * Added pageindextext to MAPINFO/Gameinfo.
  * Added $musicalias to SNDINFO.
  * Added Super 3-D Noah's Ark MIDI->OPL code.
  * Fading has been reworked to allow overlaying fades over game
    play.
  * Support for blend and alpha mixing in TEXTURES.
  * Support for colormaps with 64 light levels like Blake Stone.
  * Partial support for Blake Stone map meta data.
  * Support for Blake Stone's level name strings as LEVELDSC.
  * Support for Macintosh Wolf3D's MAPLIST.
  * Added support for offset() in DECORATE states.
  * Pickups support Hide state to allow spent pickups to be visible
  * Added Idle state for actors to return to if they lose their
    target.
  * Files can be autoloaded though ecwolf.cfg.
  * Added game based content filtering for PK3s from ZDoom.
  * Default FOV can be changed through DesiredFOV in ecwolf.cfg.
  * Added Pushwall_MoveNoStop line special which allows moving
    pushwalls through walls like Mac Wolf and ROTT.
  * Added Teleport_Relative line special which works similarly to
    ROTT elevators without the theatrics.
  * Wall and plane drawing has been modified to generally have
    better precision.
  * Added trackhighscores property to MAPINFO/Gameinfo.
  * Added resethealth and resetinventory to MAPINFO/Map
    definition.
  * Enemies can now accept health items.
  * Added A_Wander.
  * Added SmartAnimation actor to support Blake Stone's "smart
    animation" system.
  * Added --foreignsaves option to force saves to load even if
    game data check fails.
  * Added --skill option to select skill level by number
    particularly for when more than 4 skill levels are present.
  * Added ROTT style tall walls and ROTT's map height marker with
    feature flag "planedepth".
  * Actor z-heights are now rendered and can be set in info plane
    with "zheights" enabled in map translator (compatible with
    ROTT).
  * ROTT map loader no longer synthesizes a third plane but
    instead relies on the map translator flag "globalflat".
  * Support for ROTT's song numbers in map translator.
  * Partial support for booting Macintosh Wolfenstein 3D,
    Blake Stone: Planet Strike, and Rise of the Triad.
  * Includes support for several new data formats most of which
    have no practical use outside of loading vanilla compatible
    data.
  * Macintosh Wolfenstein 3D data is supported through macbin
    format.
  * Feature is hidden behind ShowPreviewGames in ecwolf.cfg as
    they're not yet supported or fully playable.
  * Improvements in holowall support.
  * Fixed some long standing minor memory leaks.
  * New icon/logo by NeuralStunner.
  * Support for more ultrawide aspect ratios.
  * Automap panning speed is now dependent on zoom level.
  * Fixed crash if no sound device was present.
  * Fixed cases where adaptive frame rate would fail and game would
    run too fast.
  * Customized SDL_mixer is still suggested but no longer required
    for full functionality as the only feature missing is support
    for alternate spelling of LOOP_START and LOOP_END tags.
  * Steam and GOG support updated to support new releases.
  * Remove patchutil from ECWolf source code
* Sun Feb 17 2019 Martin Hauke <mardnh@gmx.de>
- Simplified specfile
- Use proper source url
- Use %%cmake macro
- Run spec-cleaner
- Build ecwolf-patchutil
- Add patch:
  * ecwolf-static-libs.patch
* Mon Sep 25 2017 kah0922@gmail.com
- Initial package
- Cleaned spec file
